@@ -516,4 +516,30 @@ class StoreExt(db.Model):
 
     store_id = db.Column(db.Integer, primary_key=True)
     black_mode = db.Column(db.Integer, nullable=False, server_default=db.FetchedValue(), info='黑名单模式 0 不开启 1 开启')
-    white_prefix = db.Column(db.String(1000), server_default=db.FetchedValue(), info='白名单前缀 多个逗号隔开')
\ No newline at end of file
+    white_prefix = db.Column(db.String(1000), server_default=db.FetchedValue(), info='白名单前缀 多个逗号隔开')
+    expires = db.Column(db.Integer, nullable=False, server_default=db.FetchedValue(), info='认证过期时间 单位：s')
+
+
+
+class Whitelist(db.Model):
+    __tablename__ = 'whitelist'
+
+    id = db.Column(db.Integer, primary_key=True)
+    created_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
+    updated_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
+    mac = db.Column(db.String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址')
+    store_id = db.Column(db.Integer, nullable=False, index=True, server_default=db.FetchedValue(), info='场所ID号')
+    device_id = db.Column(db.Integer, nullable=False, index=True, info='设备ID号')
+    source = db.Column(db.Integer, nullable=False, index=True, info='0 手动 1 自动 21 任子行 22 百卓')
+
+
+
+class WhitelistPrefix(db.Model):
+    __tablename__ = 'whitelist_prefix'
+
+    id = db.Column(db.Integer, primary_key=True)
+    created_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
+    updated_at = db.Column(db.DateTime, nullable=False, server_default=db.FetchedValue())
+    prefix = db.Column(db.String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址前缀')
+    store_id = db.Column(db.Integer, nullable=False, index=True, server_default=db.FetchedValue(), info='场所ID号')
+    tags = db.Column(db.String(400, 'utf8mb4_general_ci'), nullable=False, server_default=db.FetchedValue(), info='标签 逗号隔开')
\ No newline at end of file
