@@ -517,4 +517,30 @@ class StoreExt(Base):
 
     store_id = Column(Integer, primary_key=True)
     black_mode = Column(Integer, nullable=False, server_default=FetchedValue(), info='黑名单模式 0 不开启 1 开启')
-    white_prefix = Column(String(1000), server_default=FetchedValue(), info='白名单前缀 多个逗号隔开')
\ No newline at end of file
+    white_prefix = Column(String(1000), server_default=FetchedValue(), info='白名单前缀 多个逗号隔开')
+    expires = Column(Integer, nullable=False, server_default=FetchedValue(), info='认证过期时间 单位：s')
+
+
+
+class Whitelist(Base):
+    __tablename__ = 'whitelist'
+
+    id = Column(Integer, primary_key=True)
+    created_at = Column(DateTime, nullable=False, server_default=FetchedValue())
+    updated_at = Column(DateTime, nullable=False, server_default=FetchedValue())
+    mac = Column(String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址')
+    store_id = Column(Integer, nullable=False, index=True, server_default=FetchedValue(), info='场所ID号')
+    device_id = Column(Integer, nullable=False, index=True, info='设备ID号')
+    source = Column(Integer, nullable=False, index=True, info='0 手动 1 自动 21 任子行 22 百卓')
+
+
+
+class WhitelistPrefix(Base):
+    __tablename__ = 'whitelist_prefix'
+
+    id = Column(Integer, primary_key=True)
+    created_at = Column(DateTime, nullable=False, server_default=FetchedValue())
+    updated_at = Column(DateTime, nullable=False, server_default=FetchedValue())
+    prefix = Column(String(17, 'utf8mb4_general_ci'), nullable=False, index=True, info='mac地址前缀')
+    store_id = Column(Integer, nullable=False, index=True, server_default=FetchedValue(), info='场所ID号')
+    tags = Column(String(400, 'utf8mb4_general_ci'), nullable=False, server_default=FetchedValue(), info='标签 逗号隔开')
\ No newline at end of file
